@@ -18,14 +18,14 @@ def run_pred_step(test_loader, model, x_cat=None, target=False):
     device = "cpu"
     model.eval()
 
-    pred_list = []
+    # pred_list = []
     for batch, data in enumerate(test_loader):
         x = data['num_features'].to(device)
         if x_cat is not None:
             x_cat = data['cat_features'].to(device)
         with torch.torch.no_grad():
             pred = model(x, x_cat).to(device).detach().numpy()
-        pred_list.append(pred.squeeze())
+        # pred_list.append(pred.squeeze())
 
-    return pred_list
+    return pred
             
\ No newline at end of file
