@@ -140,7 +140,7 @@ def dataloader_by_stock(
     cont, cat = cont_cat_split(df, cat_cols=cat_cols)
     # print('continouscols:', cont.columns)
     
-    print('continuos shape:', cont.shape, '', 'categorical shape:', cat.shape)
+    # print('continuos shape:', cont.shape, '', 'categorical shape:', cat.shape)
     
     df_train_cat, df_val_cat = ts_split(cat)
     # print('cat_columns:', df_train_cat.columns)
@@ -182,24 +182,29 @@ def dataloader_test_by_stock(
     batch_size=32,  
     continous_cols=['Close'],
     target_col='Target',
-    return_idx=True
+    return_idx=True,
+    date=None,
     ):
     df = df[df['SecuritiesCode'] == sec_code].drop(['SecuritiesCode'], axis=1)
     df = date_features(df)
+    if date:
+        df.reset_index(inplace=True)
+        df = df[df['Date'] == date]
+        df.set_index('Date', inplace=True)
 
     """Hard coded cat-columns"""
     cat_cols = ['day_of_year', 'month', 'day_of_week', 'RowId', 'Section/Products', '33SectorName', '17SectorName']
     cont, cat = cont_cat_split(df, cat_cols=cat_cols)
     
-    print('continuos shape:', cont.shape, '', 'categorical shape:', cat.shape)
+    # print('continuos shape:', cont.shape, '', 'categorical shape:', cat.shape)
     xtest, idx = preprocess(cont, target_col, 1, continous_cols=continous_cols, return_idx=return_idx)
 
     if len(xtest) == 1:
         xtest = xtest.reshape(1, -1)
     if transformer is not None:
         xtest = transformer.transform(xtest)
-    else:
-        print('Notice that the transformer is None.')
+    # else:
+    #     print('Notice that the transformer is None.')
 
     test_dataloader = get_predict_loader(
         x=xtest, 
